calc_dens_hist: Calculate scaled 1d density
Description
Calculates 1d density of age data and scales it so that it can be plotted
in the same plot of a histogram of the age data
Usage
calc_dens_hist(
dat,
binwidth = 50,
bw = 30,
type = "kde",
age_range = c(0, 4560)
)
Arguments
type
'kde': KDE; 'pdd': detrital zircon PDD
age_range
Age range to calculated density over