check_conc: Check concordancy of input ages
Description
Check the concordancy of the U-Pb data and return the data within the desired
discordancy limit.
Usage
check_conc(dat, disc_lim = 10)
Arguments
dat
data.frame containing at least ages and percentage of discordancy